//
//  ViewController.swift
//  FileManager
//
//  Created by Keith Welch on 9/14/15.
//  Copyright © 2015 Keith Welch. All rights reserved.
//

import UIKit

class ViewController: UIViewController {

    @IBOutlet weak var txtOutput: UITextView!
    
    var fileManager:NSFileManager!
    var documentsDirectory:NSString!
    
    override func viewDidLoad() {
        super.viewDidLoad()

        fileManager = NSFileManager.defaultManager()
    }

    func logToTextView(log: NSString)
    {
        txtOutput.text = txtOutput.text.stringByAppendingFormat("%@\n",log)
    }
    
    func logError(error: NSError)
    {
        logToTextView(NSString(format: "\n****ERROR****\n\n%@", error.description))
    }

    @IBAction func btnRunTouched(sender: AnyObject) {
        let subDirPath:NSString
        
        logToTextView("Starting File Manager Operations")
        
        //
        // Step 1 - Find the documents directory
        //
        let paths:NSArray = NSSearchPathForDirectoriesInDomains(.DocumentDirectory, .UserDomainMask, true)
        documentsDirectory = paths[0] as! NSString
        logToTextView(NSString(format: "Documents directory is: %@", self.documentsDirectory))
        
        //
        // Step 2 - Create a sub-directory
        //
        subDirPath = documentsDirectory.stringByAppendingPathComponent("mydir")
        
        
        do {
            try fileManager.createDirectoryAtPath(subDirPath as String, withIntermediateDirectories: false, attributes: nil)
            logToTextView("---- Created mydir successfully")
        }
        catch let error as NSError {
            logError(error)
        }
        
        //
        // Step 3 - Write some data to a file
        //
        let fileData:NSString = "This is data for our file\n\nSince it's a text file you can open it in TextEdit to verify\n"
        let filePath:NSString = subDirPath.stringByAppendingPathComponent("sample.txt")
        
        do {
            try fileData.writeToFile(filePath as String, atomically: false, encoding: NSUTF8StringEncoding)
            logToTextView("---- sample.txt written successfully")
        }
        catch let error as NSError {
            logError(error)
        }
        
        if (fileManager.fileExistsAtPath(filePath as String))
        {
            logToTextView("File exists after writing")
        }
        
        //
        // Step 4 - Read the data back from the file
        //
        do {
            let dataFromFile:String = try String(contentsOfFile: filePath as String, encoding:NSUTF8StringEncoding)
            logToTextView(String(format:"---- Data read from file: %@", dataFromFile))
        }
        catch let error as NSError {
            logError(error)
        }

        //
        // Step 5 - Create a couple more files
        //
        let filePath2:NSString = subDirPath.stringByAppendingPathComponent("sample2.txt")
        let filePath3:NSString = subDirPath.stringByAppendingPathComponent("sample3.txt")
        
        do {
            try fileData.writeToFile(filePath2 as String, atomically: false, encoding: NSUTF8StringEncoding)
            logToTextView("---- sample2.txt written successfully")
        }
        catch let error as NSError {
            logError(error)
        }
        
        do {
            try fileData.writeToFile(filePath3 as String, atomically: false, encoding: NSUTF8StringEncoding)
            logToTextView("---- sample3.txt written successfully")
        }
        catch let error as NSError {
            logError(error)
        }
        
        //
        // Step 6 - Get contents of directory
        //
        logToTextView("\n\nFiles in directory are:\n")

        do {
            let items = try fileManager.contentsOfDirectoryAtPath(subDirPath as String)
            for item in items as [String] {
                logToTextView(item)
            }
        }
        catch let error as NSError {
            logError(error)
        }
        
    }
    
    override func didReceiveMemoryWarning() {
        super.didReceiveMemoryWarning()
        // Dispose of any resources that can be recreated.
    }


}

