//
//  ViewController.swift
//  RemindersAlarms
//
//  Created by Keith Welch on 9/14/15.
//  Copyright © 2015 Keith Welch. All rights reserved.
//

import UIKit
import EventKit

class ViewController: UIViewController {

    var eventStore:EKEventStore!
    var eventStoreAccessGranted:ObjCBool!
    
    override func viewDidLoad() {
        super.viewDidLoad()
        
        //
        // First, we determine if we have access to the event (calendar) store for adding
        // reminders and alarms
        //
        eventStore = EKEventStore()
        eventStoreAccessGranted = false
        
        eventStore.requestAccessToEntityType(EKEntityType.Reminder, completion: {(success, error) -> Void in
            self.eventStoreAccessGranted = success
            if (!success) {
                NSLog("User has not granted access to add reminders.")
            }
        })

    }

    @IBAction func btnAddReminderTouched(sender: AnyObject) {
        
        if (eventStoreAccessGranted == nil){
            return
        }
        
        let newReminder:EKReminder = EKReminder(eventStore: self.eventStore)
        
        newReminder.title = "Watch next movie in the course"
        newReminder.calendar = eventStore.defaultCalendarForNewReminders()
        
        do {
            try eventStore.saveReminder(newReminder, commit: true)
        }
        catch let error as NSError {
            NSLog(error.description)
        }
    }

    @IBAction func btnAddAlarmTouched(sender: AnyObject) {

        if (eventStoreAccessGranted == nil){
            return
        }

        //
        // Get the current date/time
        //
        let now:NSDate = NSDate()
        
        //
        // Add 10 seconds
        //
        let alarmDate:NSDate = now.dateByAddingTimeInterval(10)
        
        let ourAlarm:EKAlarm = EKAlarm(absoluteDate: alarmDate)
        
        let newReminder:EKReminder = EKReminder(eventStore: self.eventStore)
        
        newReminder.title = "Stand up and stretch"
        newReminder.calendar = eventStore.defaultCalendarForNewReminders()
        newReminder.addAlarm(ourAlarm)
        
        do {
            try eventStore.saveReminder(newReminder, commit: true)
        }
        catch let error as NSError {
            NSLog(error.description)
        }
    }
    
    override func didReceiveMemoryWarning() {
        super.didReceiveMemoryWarning()
    }


}

